<?php

namespace Drupal\wordfilter\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\wordfilter\Plugin\WordfilterProcessInterface;
use Drupal\wordfilter\WordfilterItem;

/**
 * Provides an interface for defining Wordfilter configuration entities.
 */
interface WordfilterConfigurationInterface extends ConfigEntityInterface {

  /**
   * Get the assigned filtering process.
   *
   * @return \Drupal\wordfilter\Plugin\WordfilterProcessInterface
   *   The assigned filtering process.
   */
  public function getProcess(): WordfilterProcessInterface;

  /**
   * Assign the filtering process.
   *
   * @param \Drupal\wordfilter\Plugin\WordfilterProcessInterface $process
   *   The Wordfilter process to assign.
   */
  public function setProcess(WordfilterProcessInterface $process);

  /**
   * Get the filtering items.
   *
   * @return \Drupal\wordfilter\WordfilterItem[]
   *   An array of filtering items, keyed and sorted by delta.
   */
  public function getItems(): array;

  /**
   * Creates a new item, which is part of this configuration.
   *
   * You may also use this function to "reset" a given item to empty values.
   *
   * @param int|null $delta
   *   (Optional) The delta for the new item.
   *
   * @return \Drupal\wordfilter\WordfilterItem
   *   Word filter item.
   */
  public function newItem(?int $delta = NULL): WordfilterItem;

  /**
   * Remove the filtering item from this configuration.
   *
   * The item must belong to this configuration,
   * otherwise it won't be removed.
   *
   * @param \Drupal\wordfilter\WordfilterItem $item_object
   *   Word filter item.
   *
   * @return bool
   *   TRUE if removal was successful, FALSE otherwise.
   */
  public function removeItem(WordfilterItem $item_object): bool;

}
