<?php

namespace Drupal\wordfilter\Plugin\WordfilterProcess;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Component\Utility\Xss;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\wordfilter\Attribute\WordFilterProcess;
use Drupal\wordfilter\Entity\WordfilterConfigurationInterface;
use Drupal\wordfilter\Plugin\WordfilterProcessBase;

/**
 * Default word filter process plugin.
 */
#[WordFilterProcess(
  id: 'default',
  label: new TranslatableMarkup("Direct substitution (default)"),
  description: new TranslatableMarkup("All specified filter words will be directly replaced with the specified substitution text by using a simple and automatically generated regular expression."),
)]
class DefaultWordfilterProcess extends WordfilterProcessBase {

  /**
   * {@inheritdoc}
   */
  public function filterWords(string $text, WordfilterConfigurationInterface $wordfilter_config, string $langcode = LanguageInterface::LANGCODE_NOT_SPECIFIED): string {
    foreach ($wordfilter_config->getItems() as $item) {
      $filter_words = $item->getFilterWords();
      $filter_words = $this->prepareWordsForRegex($filter_words);

      $filter_pattern = '/' . implode('|', $filter_words) . '/iu';
      $substitute = Xss::filterAdmin($item->getSubstitute());

      $text = preg_replace($filter_pattern, $substitute, $text);
    }
    return $text;
  }

}
