<?php

namespace Drupal\wordfilter\Plugin\WordfilterProcess;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Component\Utility\Xss;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Utility\Token;
use Drupal\wordfilter\Attribute\WordFilterProcess;
use Drupal\wordfilter\Entity\WordfilterConfigurationInterface;
use Drupal\wordfilter\Plugin\WordfilterProcessBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Token word filter process plugin.
 */
#[WordFilterProcess(
  id: 'token',
  label: new TranslatableMarkup("Token substitution"),
  description: new TranslatableMarkup("Similar to the default process, all specified filter words will be directly replaced with the substitution text. You may additionally use <a href=':url' target='_blank'>tokens</a> inside the substitution text.", [':url' => 'https://www.drupal.org/node/390482'])
)]
class TokenWordfilterProcess extends WordfilterProcessBase {

  /**
   * Constructs TokenWordfilterProcess object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Utility\Token $token
   *   Token object.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected Token $token,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('token'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function filterWords(string $text, WordfilterConfigurationInterface $wordfilter_config, string $langcode = LanguageInterface::LANGCODE_NOT_SPECIFIED): string {
    foreach ($wordfilter_config->getItems() as $item) {
      $filter_words = $item->getFilterWords();
      $filter_words = $this->prepareWordsForRegex($filter_words);

      $filter_pattern = '/' . implode('|', $filter_words) . '/iu';
      $substitute = Xss::filterAdmin($item->getSubstitute());
      $substitute = $this->token->replace($substitute);

      $text = preg_replace($filter_pattern, $substitute, $text);
    }
    return $text;
  }

}
