<?php

namespace Drupal\Tests\wordfilter\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\wordfilter\Entity\WordfilterConfiguration;
use Drupal\wordfilter\Plugin\WordfilterProcess\DefaultWordfilterProcess;
use Drupal\wordfilter\Plugin\WordfilterProcessInterface;

/**
 * @coversDefaultClass \Drupal\wordfilter\Plugin\WordfilterProcess\DefaultWordfilterProcess
 * @group filter
 */
class DefaultWordfilterProcessUnitTest extends UnitTestCase {

  /**
   * Word filter process.
   *
   * @var \Drupal\wordfilter\Plugin\WordfilterProcessInterface|null
   */
  protected ?WordfilterProcessInterface $wordfilterProcess = NULL;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->wordfilterProcess = new DefaultWordfilterProcess([], 'default', []);
  }

  /**
   * @covers ::filterWords
   *
   * @dataProvider providerFilterWords
   *
   * @param string $text
   *   An unfiltered string with words.
   * @param string $expected
   *   The expected output string.
   */
  public function testfilterWords(string $text, string $expected): void {
    $config = new WordfilterConfiguration([
      'id' => 'my_superduper_wordfilter_configuration',
      'label' => 'My superduper Wordfilter configuration',
    ],
      'wordfilter_configuration');
    $items = $config->getItems();
    $item = reset($items);
    $item->setFilterWords(['(Lorem)', 'Dolor', 'Amet', '漢']);
    $item->setSubstitute('***');

    $process = $this->wordfilterProcess;
    $this->assertSame($expected, $process->filterWords($text, $config));
  }

  /**
   * Data provider for testfilterWords().
   *
   * @todo Add more reasonable data sets.
   */
  public static function providerFilterWords(): array {
    return [
      ['Lorem Ipsum Dolor Sit Amet', 'Lorem Ipsum *** Sit ***'],
      ['lorem ipsum dolor sit amet', 'lorem ipsum *** sit ***'],
      ['LoremIpsumDolorSitAmet', 'LoremIpsumDolorSitAmet'],
      ['(Lorem) *Ipsum* *Dolor* *Sit* *Amet*', '*** *Ipsum* ***** *Sit* *****'],
      ['漢 *Ipsum* *Dolor* *Sit* *Amet*', '*** *Ipsum* ***** *Sit* *****'],
    ];
  }

}
