<?php

namespace Drupal\Tests\wordfilter\Unit;

use Drupal\Core\Utility\Token;
use Drupal\Tests\UnitTestCase;
use Drupal\wordfilter\Entity\WordfilterConfiguration;
use Drupal\wordfilter\Plugin\WordfilterProcess\TokenWordfilterProcess;
use Drupal\wordfilter\Plugin\WordfilterProcessInterface;

/**
 * @coversDefaultClass \Drupal\wordfilter\Plugin\WordfilterProcess\TokenWordfilterProcess
 * @group filter
 */
class TokenWordfilterProcessUnitTest extends UnitTestCase {

  /**
   * Word filter process.
   *
   * @var \Drupal\wordfilter\Plugin\WordfilterProcessInterface|null
   */
  protected ?WordfilterProcessInterface $wordfilterProcess = NULL;

  /**
   * {@inheritdoc}
   *
   * @throws \PHPUnit\Framework\MockObject\Exception
   */
  protected function setUp(): void {
    parent::setUp();

    $configuration = [];
    $plugin_id = 'token_wordfilter';
    $plugin_definition = [];

    $token = $this->createMock(Token::class);

    $this->wordfilterProcess = new TokenWordfilterProcess(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $token
    );

    $token = $this->getMockBuilder('\Drupal\Core\Utility\Token')
      ->disableOriginalConstructor()->getMock();

    $container = $this->createMock('Symfony\Component\DependencyInjection\ContainerInterface');
    $container->expects($this->any())
      ->method('get')
      ->with('token')
      ->willReturn($token);
    \Drupal::setContainer($container);
  }

  /**
   * @covers ::filterWords
   *
   * @dataProvider providerFilterWordsWithToken
   *
   * @param string $text
   *   An unfiltered string with words.
   * @param string $expected
   *   The expected output string.
   */
  public function testfilterWordsWithToken(string $text, string $expected): void {
    $config = new WordfilterConfiguration([
      'id' => 'my_superduper_wordfilter_configuration',
      'label' => 'My superduper Wordfilter configuration',
    ],
      'wordfilter_configuration');
    $items = $config->getItems();
    $item = reset($items);
    $item->setFilterWords(['(Lorem)', 'Dolor', 'Amet']);
    $item->setSubstitute('[any:token]');

    $process = $this->wordfilterProcess;
    $this->assertSame($expected, $process->filterWords($text, $config));
  }

  /**
   * Data provider for testfilterWordsWithToken().
   *
   * @todo Add more reasonable data sets.
   */
  public static function providerFilterWordsWithToken(): array {
    return [
      ['Lorem Ipsum Dolor Sit Amet', 'Lorem Ipsum  Sit '],
      ['lorem ipsum dolor sit amet', 'lorem ipsum  sit '],
      ['LoremIpsumDolorSitAmet', 'LoremIpsumDolorSitAmet'],
      ['(Lorem) *Ipsum* *Dolor* *Sit* *Amet*', ' *Ipsum* ** *Sit* **'],
    ];
  }

  /**
   * @covers ::filterWords
   *
   * @dataProvider providerFilterWordsWithToken
   *
   * @param string $text
   *   An unfiltered string with words.
   * @param string $expected
   *   The expected output string.
   */
  public function testfilterWordsWithoutToken(string $text, string $expected) {
    $config = new WordfilterConfiguration([
      'id' => 'my_superduper_wordfilter_configuration',
      'label' => 'My superduper Wordfilter configuration',
    ],
      'wordfilter_configuration');
    $items = $config->getItems();
    $item = reset($items);
    $item->setFilterWords(['(Lorem)', 'Dolor', 'Amet']);
    $item->setSubstitute('***');

    $process = $this->wordfilterProcess;
    $this->assertSame($expected, $process->filterWords($text, $config));
  }

  /**
   * Data provider for testfilterWordsWithoutToken().
   *
   * @todo Add more reasonable data sets.
   */
  public static function providerFilterWordsWithoutToken(): array {
    return [
      ['Lorem Ipsum Dolor Sit Amet', 'Lorem Ipsum *** Sit ***'],
      ['lorem ipsum dolor sit amet', 'lorem ipsum *** sit ***'],
      ['LoremIpsumDolorSitAmet', 'LoremIpsumDolorSitAmet'],
      ['(Lorem) *Ipsum* *Dolor* *Sit* *Amet*', '*** *Ipsum* ***** *Sit* *****'],
    ];
  }

}
